cast_bases_mut

Function cast_bases_mut 

pub fn cast_bases_mut<FSub, P>(
    packed: &mut [P],
) -> &mut [PackedSubfield<P, FSub>] 
where FSub: BinaryField, P: PackedField<Scalar: ExtensionField<FSub>> + WithUnderlier, PackedSubfield<P, FSub>: PackedField<Scalar = FSub>,
Reinterpret a mutable slice of packed extension field elements as a mutable slice of the corresponding packed subfield elements.

The two slices share the same memory; PackedSubfield<P, FSub> has the same underlier as P.