PackedSubfield

Type Alias PackedSubfield 

pub type PackedSubfield<P, FSub> = PackedPrimitiveType<<P as UnderlierView>::Underlier, FSub>;
The packing of FSub covering the same bits as the packed extension field type P.

A transparent wrapper over an underlier holds one contiguous bit string. Cutting that same string into FSub scalars is exactly a PackedPrimitiveType.

Aliased Type

#[repr(transparent)]
pub struct PackedSubfield<P, FSub>(pub <P as UnderlierView>::Underlier, pub PhantomData<FSub>);

Tuple Fields

0: <P as UnderlierView>::Underlier1: PhantomData<FSub>