pub fn cast_base_mut<FSub, P>(packed: &mut P) -> &mut PackedSubfield<P, FSub>where
FSub: BinaryField,
P: PackedField<Scalar: ExtensionField<FSub>> + WithUnderlier,
PackedSubfield<P, FSub>: PackedField<Scalar = FSub>,Expand description
Reinterpret a mutable reference to a packed extension field element as a mutable reference to the corresponding packed subfield element.